@@ -20,18 +20,17 @@ def parse_option() -> argparse.Namespace:
             """
         ),
     )
-    parser.add_argument(
-        "-V", "--version", action="version", version="%(prog)s {}".format(__version__)
-    )
+    parser.add_argument("-V", "--version", action="version", version=f"%(prog)s {__version__}")
+    parser.add_argument("-v", "--verbose", dest="verbosity_level", action="count", default=1)
 
     parser.add_argument(
-        "--packages",
-        default="",
-        help="comma-separated packages that extract versions.",
+        "packages",
+        nargs="+",
+        help="packages to extract versions",
     )
     parser.add_argument(
         "--format",
-        choices=["text", "markdown"],
+        choices=["text", "markdown", "json"],
         default="text",
         help="output format",
     )
@@ -40,9 +39,9 @@ def parse_option() -> argparse.Namespace:
 
 
 def main() -> None:
-    options = parse_option()
+    ns = parse_option()
 
-    print(dumps(options.packages.split(","), options.format))
+    print(dumps(ns.packages, ns.format, verbosity_level=ns.verbosity_level))
 
 
 if __name__ == "__main__":
